@@ -89,7 +89,7 @@ class TelWidget(TextInputWidget):
         quoted = quoteattr(cstruct)
         if readonly:
             return cstruct
-        return u'<input type="tel" name="%s" pattern="(\\d| )+" value=%s>' % (
+        return u'<input type="tel" name="%s" pattern="(^\\+?\\d*$)" value=%s>' % (
             field.name,
             quoted,
         )
@@ -103,12 +103,21 @@ class Photo(FileData, Base):
     __colanderalchemy_config__ = {
         "title": _("Photo"),
         "unknown": "preserve",
+        "missing": colander.required,
         "widget": deform_ext.FileUploadWidget(
-            get_url=lambda request, id: request.route_url(
-                "c2cgeoform_item", table="photos", id=id
-            )
+            id_field="hash",
+            get_url=lambda request, id_: request.route_url(
+                "c2cgeoform_item", table="photos", id=id_
+            ),
         ),
     }
+    hash = Column(
+        Text,
+        nullable=False,
+        unique=True,
+        default=lambda: str(uuid4()),
+        info={"c2cgeoform": {"duplicate": False}},
+    )
     issue_id = Column(Integer, ForeignKey("{}.issue.id".format(schema)))
 
 
@@ -282,7 +291,9 @@ class Issue(Base):
             "colanderalchemy": {
                 "title": _("Status"),
                 "widget": SelectWidget(
-                    values=STATUSES.items(), readonly=True, item_css_class="item-status"
+                    values=list(STATUSES.items()),
+                    readonly=True,
+                    item_css_class="item-status",
                 ),
             }
         },
@@ -315,24 +326,17 @@ class Issue(Base):
         },
     )
     localisation = Column(
-        String(254),
-        nullable=False,
-        info={"colanderalchemy": {"title": _("Localisation")}},
+        String(254), info={"colanderalchemy": {"title": _("Localisation")}}
     )
     photos = relationship(
         Photo,
         cascade="all, delete-orphan",
         info={"colanderalchemy": {"title": _("Photos")}},
     )
-    firstname = Column(
-        String(100), nullable=False, info={"colanderalchemy": {"title": _("Firstname")}}
-    )
-    lastname = Column(
-        String(100), nullable=False, info={"colanderalchemy": {"title": _("Lastname")}}
-    )
+    firstname = Column(String(100), info={"colanderalchemy": {"title": _("Firstname")}})
+    lastname = Column(String(100), info={"colanderalchemy": {"title": _("Lastname")}})
     phone = Column(
         String(20),
-        nullable=False,
         info={"colanderalchemy": {"title": _("Phone"), "widget": TelWidget()}},
     )
     email = Column(
@@ -376,6 +380,9 @@ class Issue(Base):
     def icon_url(self, request):
         return self.type.icon_url(request) if self.type else default_icon_url(request)
 
+    def full_name(self):
+        return "{} {}".format(self.firstname or "", self.lastname or "").strip()
+
 
 class Event(Base):
     __tablename__ = "event"
@@ -399,7 +406,7 @@ class Event(Base):
             "colanderalchemy": {
                 "title": _("Status"),
                 "widget": SelectWidget(
-                    values=STATUSES.items(), item_css_class="item-status"
+                    values=list(STATUSES.items()), item_css_class="item-status"
                 ),
             }
         },
